schedule_task_deletion

Function schedule_task_deletion 

pub unsafe fn schedule_task_deletion(task_handle: Option<ThreadPtr>)
Schedules the given task for deletion.

Passing None will schedule the current task to be deleted.

Safety

The task_handle must be a pointer to a task, obtained either by calling task_create or current_task.