pub fn usleep_until(target: u64)Expand description
Puts the current task to sleep until the specified timestamp.
The timestamp is measured in microseconds, from the time the timer was started.
pub fn usleep_until(target: u64)Puts the current task to sleep until the specified timestamp.
The timestamp is measured in microseconds, from the time the timer was started.